@@ -325,7 +325,6 @@ restartR <- function(sim, reloadPkgs = TRUE, .First = NULL,
 
   sim$._restartRList$opts <- options()
   if ("raster" %in% attached) {
-    browser() # convert raster
     invisible(capture.output({
       sim$._restartRList$optsRaster <- raster::rasterOptions()
     }))
@@ -338,7 +337,6 @@ restartR <- function(sim, reloadPkgs = TRUE, .First = NULL,
     paddedFloatToChar(time(sim), padL = nchar(as.character(end(sim))))))
 
   ## ensure correct file extension
-  browser() # this next function will add or swap -- tools::file_ext doesn't swap
   sim$._restartRList$simFilename <- raster::extension(sim$._restartRList$simFilename, ".qs")
 
   # sim$._restartRList$endOrig <- end(sim)
@@ -442,7 +440,6 @@ First <- function(...) {
 
   do.call(options, sim$._restartRList$opts)
   if ("raster" %in% attached) {
-    browser()
     do.call(raster::rasterOptions, sim$._restartRList$optsRaster)
   }
 
