@@ -1,13 +1,5 @@
 test_that("test objectSynonyms", {
-  skip_if_not_installed("NLMR")
-
-  testInitOut <- testInit(opts = list(spades.moduleCodeChecks = FALSE,
-                                      spades.useRequire = FALSE#,
-                                      #reproducible.useMemoise = FALSE
-                                      ))
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(sampleModReqdPkgs, opts = list(spades.useRequire = FALSE))
   sim <- simInit()
 
   sim$age <- 1:10;
@@ -29,7 +21,7 @@ test_that("test objectSynonyms", {
     randomLandscapes = list(inRAM = TRUE, nx = 15, ny = 15)
   )
   modules <- list("randomLandscapes", "caribouMovement")
-  paths <- list(modulePath = system.file("sampleModules", package = "SpaDES.core"))
+  paths <- list(modulePath = getSampleModules(tmpdir))
 
   sim <- simInit(times, params, modules, objects = list(), paths)
   sim <- objectSynonyms(sim, list(c("caribou", "caribouObj")))
@@ -68,10 +60,10 @@ test_that("test objectSynonyms", {
       name = "test",
       description = "insert module description here",
       keywords = c("insert key words here"),
-      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@canada.ca", role = c("aut", "cre")),
+      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@nrcan-rncan.gc.ca", role = c("aut", "cre")),
       childModules = character(0),
       version = list(SpaDES.core = "0.1.0", test = "0.0.1"),
-      spatialExtent = raster::extent(rep(NA_real_, 4)),
+      spatialExtent = terra::ext(rep(0, 4)),
       timeframe = as.POSIXlt(c(NA, NA)),
       timeunit = "second",
       citation = list("citation.bib"),
@@ -152,6 +144,8 @@ test_that("test objectSynonyms", {
   expect_equal(sim$studyArea, sim$studyArea2)
   expect_true(isTRUE(sim$worked))
 
+  # On June 20, 2023, the final expectation was changed to false from true because it seems
+  #   correct that sim$worked should not be TRUE -- ageMap is not going to suppliedElsewhere
   # test simInitAndSpades with Caching/memoising with NULL objects in the active bindings
   sim <- Cache(simInitAndSpades, times, params, modules = modules,
                objects = list(objectSynonyms = os),
@@ -159,7 +153,7 @@ test_that("test objectSynonyms", {
   expect_equal(sim$age, sim$ageMap)
   expect_equal(sim$veg, sim$vegMap)
   expect_equal(sim$studyArea, sim$studyArea2)
-  expect_true(isTRUE(sim$worked))
+  expect_false(isTRUE(sim$worked))
 
   sim <- Cache(simInitAndSpades, times, params, modules = modules,
                objects = list(objectSynonyms = os),
@@ -167,5 +161,5 @@ test_that("test objectSynonyms", {
   expect_equal(sim$age, sim$ageMap)
   expect_equal(sim$veg, sim$vegMap)
   expect_equal(sim$studyArea, sim$studyArea2)
-  expect_true(isTRUE(sim$worked))
+  expect_false(isTRUE(sim$worked))
 })
